==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ProviderHubMetadataThirdPartyProviderAuthorizationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ProviderHubMetadataThirdPartyProviderAuthorizationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property authorizations
 * @property managedByTenantId
 */
public data class ProviderHubMetadataThirdPartyProviderAuthorizationArgs(
    public val authorizations: Output<List<LightHouseAuthorizationArgs>>? = null,
    public val managedByTenantId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ProviderHubMetadataThirdPartyProviderAuthorizationArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ProviderHubMetadataThirdPartyProviderAuthorizationArgs =
        com.pulumi.azurenative.providerhub.inputs.ProviderHubMetadataThirdPartyProviderAuthorizationArgs.builder()
            .authorizations(
                authorizations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .managedByTenantId(managedByTenantId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ProviderHubMetadataThirdPartyProviderAuthorizationArgs].
 */
@PulumiTagMarker
public class ProviderHubMetadataThirdPartyProviderAuthorizationArgsBuilder internal constructor() {
    private var authorizations: Output<List<LightHouseAuthorizationArgs>>? = null

    private var managedByTenantId: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("ubkgfesyvixdccxi")
    public suspend fun authorizations(`value`: Output<List<LightHouseAuthorizationArgs>>) {
        this.authorizations = value
    }

    @JvmName("asrjplyebqoihtdv")
    public suspend fun authorizations(vararg values: Output<LightHouseAuthorizationArgs>) {
        this.authorizations = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("odpududfwegkwhod")
    public suspend fun authorizations(values: List<Output<LightHouseAuthorizationArgs>>) {
        this.authorizations = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("yxtpoemmqbquspro")
    public suspend fun managedByTenantId(`value`: Output<String>) {
        this.managedByTenantId = value
    }

    /**
     * @param value
     */
    @JvmName("fyyvylkmbtstbxsi")
    public suspend fun authorizations(`value`: List<LightHouseAuthorizationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authorizations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("yifscoiynfmhphcj")
    public suspend
    fun authorizations(argument: List<suspend LightHouseAuthorizationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            LightHouseAuthorizationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.authorizations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("cleiqmgmhwtjdlgn")
    public suspend fun authorizations(
        vararg
        argument: suspend LightHouseAuthorizationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            LightHouseAuthorizationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.authorizations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("absagpswphsrledw")
    public suspend
    fun authorizations(argument: suspend LightHouseAuthorizationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            LightHouseAuthorizationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.authorizations = mapped
    }

    /**
     * @param values
     */
    @JvmName("lbtrcekkgiaqprxv")
    public suspend fun authorizations(vararg values: LightHouseAuthorizationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authorizations = mapped
    }

    /**
     * @param value
     */
    @JvmName("orskgxwivgrofqnr")
    public suspend fun managedByTenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managedByTenantId = mapped
    }

    internal fun build(): ProviderHubMetadataThirdPartyProviderAuthorizationArgs =
        ProviderHubMetadataThirdPartyProviderAuthorizationArgs(
            authorizations = authorizations,
            managedByTenantId = managedByTenantId,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ProviderHubMetadataThirdPartyProviderAuthorizationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ProviderHubMetadataThirdPartyProviderAuthorizationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property authorizations
 * @property managedByTenantId
 */
public data class ProviderHubMetadataThirdPartyProviderAuthorizationArgs(
    public val authorizations: Output<List<LightHouseAuthorizationArgs>>? = null,
    public val managedByTenantId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ProviderHubMetadataThirdPartyProviderAuthorizationArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ProviderHubMetadataThirdPartyProviderAuthorizationArgs =
        com.pulumi.azurenative.providerhub.inputs.ProviderHubMetadataThirdPartyProviderAuthorizationArgs.builder()
            .authorizations(
                authorizations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .managedByTenantId(managedByTenantId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ProviderHubMetadataThirdPartyProviderAuthorizationArgs].
 */
@PulumiTagMarker
public class ProviderHubMetadataThirdPartyProviderAuthorizationArgsBuilder internal constructor() {
    private var authorizations: Output<List<LightHouseAuthorizationArgs>>? = null

    private var managedByTenantId: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("bcljaukjqxpvtvtt")
    public suspend fun authorizations(`value`: Output<List<LightHouseAuthorizationArgs>>) {
        this.authorizations = value
    }

    @JvmName("jjwhllkrveeydjme")
    public suspend fun authorizations(vararg values: Output<LightHouseAuthorizationArgs>) {
        this.authorizations = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("nrcobccsptuywagf")
    public suspend fun authorizations(values: List<Output<LightHouseAuthorizationArgs>>) {
        this.authorizations = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("nhvymivaacmqhfjq")
    public suspend fun managedByTenantId(`value`: Output<String>) {
        this.managedByTenantId = value
    }

    /**
     * @param value
     */
    @JvmName("qdwlqlfckhgkjonn")
    public suspend fun authorizations(`value`: List<LightHouseAuthorizationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authorizations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("kblttoxjrgpnibrk")
    public suspend
    fun authorizations(argument: List<suspend LightHouseAuthorizationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            LightHouseAuthorizationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.authorizations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ahjawyfliuxhmcrw")
    public suspend fun authorizations(
        vararg
        argument: suspend LightHouseAuthorizationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            LightHouseAuthorizationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.authorizations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("vjudsarrecinglpr")
    public suspend
    fun authorizations(argument: suspend LightHouseAuthorizationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            LightHouseAuthorizationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.authorizations = mapped
    }

    /**
     * @param values
     */
    @JvmName("vfslaqmjlrequdtx")
    public suspend fun authorizations(vararg values: LightHouseAuthorizationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authorizations = mapped
    }

    /**
     * @param value
     */
    @JvmName("unudwhiiiiefvteg")
    public suspend fun managedByTenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managedByTenantId = mapped
    }

    internal fun build(): ProviderHubMetadataThirdPartyProviderAuthorizationArgs =
        ProviderHubMetadataThirdPartyProviderAuthorizationArgs(
            authorizations = authorizations,
            managedByTenantId = managedByTenantId,
        )
}
